@@ -11,7 +11,7 @@ from inspect import Parameter
 from typing import Union, List, Sequence, Optional
 
 import numpy as np
-# import torch
+
 import torch
 from sklearn.model_selection import train_test_split
 from torch import Tensor
@@ -160,24 +160,6 @@ def train_test_pack(*arrays, out=0, **options):
         return train_test_data
 
 
-def re_pbc(pbc: Union[bool, List[bool], np.ndarray], return_type="bool"):
-    if pbc is True:
-        pbc = [1, 1, 1]
-    elif pbc is False:
-        pbc = [0, 0, 0]
-    elif isinstance(pbc, abc.Iterable):
-        pbc = [1 if i == True or i == 1 else 0 for i in pbc]
-    else:
-        raise TypeError("Can't accept {}".format(pbc))
-    if return_type == "bool":
-        pbc = np.array(pbc) == 1
-    else:
-        pbc = np.array(pbc)
-    return pbc
-
-
-# a = re_pbc(np.array([True,True,False]), return_type="int")
-
 def getter_arr(obj, pi):
     """Get prop.
     """
@@ -315,7 +297,7 @@ def sparse_eg_single(edge_index, num_nodes, num_edges, edge_weight=None, **kwarg
     adj_t = SparseTensor(row=col, col=row, value=value,
                          sparse_sizes=(N, N), is_sorted=True)
 
-    return adj_t, *others
+    return adj_t, others
 
 
 def get_ptr(index):
