@@ -1,19 +1,14 @@
 import unittest
 
-import numpy as np
-import pandas as pd
 from pymatgen.core import Structure
 
-from featurebox.data.check_data import CheckElements
-from featurebox.featurizers.atom.mapper import AtomTableMap, AtomJsonMap, AtomPymatgenPropMap, BinaryMap
-from featurebox.featurizers.base_transform import ConverterCat
-from featurebox.featurizers.envir.environment import BaseDesGet
+from featurebox.featurizers.atom.mapper import AtomTableMap, AtomJsonMap
 
 
 class TestGraph(unittest.TestCase):
     def setUp(self) -> None:
         self.st = Structure.from_file("674718.cif")
-        self.st2 = [Structure.from_file("674718.cif"),Structure.from_file("674718.cif")]
+        self.st2 = [Structure.from_file("674718.cif"), Structure.from_file("674718.cif")]
 
     def test_convert(self):
         atm = AtomTableMap()
@@ -27,5 +22,3 @@ class TestGraph(unittest.TestCase):
     def test_tra(self):
         atm = AtomJsonMap(search_tp="name")
         re = atm.transform(self.st2)
-
-
